import { EventEmitter, OnChanges, SimpleChanges } from '@angular/core';
import { IChatDetail } from '../../dto/ichat-detail';
import { IChatDetailMessage } from '../../dto/ichat-detail-message';
import { EChatLock } from '../../dto/echat-lock';
/**
 * Componente donde mostramos los mensajes de la conversacion
 */
export declare class ChatDetailComponent implements OnChanges {
    /**
     * Las caracteristicas de la conversacion
     * Si se envia null en lock no podra bloquear ni desbloquear un chat
     */
    chatDetail: IChatDetail;
    /**
     * Alt en icono de trash
     */
    messageTrashIcon: string;
    /**
     * Alt en icono de trash
     */
    messageLockIcon: string;
    /**
     * Alt en icono de trash
     */
    messageUnlockIcon: string;
    /**
     * Imagen a mostrar en el chat cuando chatDetail esta vacio
     */
    imageChat: string;
    /**
     * Id del mensaje al que desea moverse
     */
    moveToMessage: number;
    /**
     * Al enviar un nuevo mensaje
     */
    newMessage: EventEmitter<IChatDetailMessage>;
    /**
     * Al eliminar la conversacion
     */
    deleteMessages: EventEmitter<any>;
    /**
     * Al bloquear una conversacion
     */
    lockChat: EventEmitter<EChatLock>;
    /**
     * Variable para usar un enum en html
     */
    EChatLock: typeof EChatLock;
    /**
     * posicion del scroll
     */
    position: [number, number];
    /**
     * Nombre del mensaje al que queremos movernos
     */
    elementName: string;
    /**
     * Variable en la cual se guarda las imagenes recibidas
     */
    filesPreview: FileList;
    /**
     * @ignore
     */
    constructor();
    /**
     * Se validara si el cambio es de movetomessage
     * Validara si se cambio de chat y eliminar previsualizacion
     * @param changes index del mensaje a mostrar
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Emitimos un nuevo mensaje y añadimos el mensaje
     * si no tiene mensajes ni imagenes no realizara ningua accion
     * @param message mensaje enviado
     */
    messageSend(message: string): void;
    /**
     * imagePreview
     * @param fileList imagenes Seleccionadas
     */
    imagePreview(fileList: FileList): void;
    /**
     * Se eliminaran los mensajes en esta conversacion
     */
    chatDelete(): void;
    /**
     * Se bloqueara la conversacion
     */
    lock(): void;
    /**
     * Se desbloqueara la conversacion
     */
    unlock(): void;
    /**
     * Valida si el estado es el esperado
     * @param state bloqueo, bloqueado o desbloqueado
     */
    lookStateValidate(state: EChatLock, expetedState: EChatLock): boolean;
    /**
     * Si la imagen es null, undefined o vacia utilizar una por defecto
     * @param image url o ubicacion de la imagen
     * @returns la imagen o una por va
     */
    imageValidate(image: string): string;
    /**
     * Validaremos la variable chat detail
     */
    validateChatDetail(): boolean;
    /**
     * Cambiar el estado de 1 o 0 a letras
     * @param state Enum del estado actual
     */
    nameState(state: number): string;
    /**
     * Vamos a mover al mensaje indicado
     * @param id id del mensaje a moverse
     */
    messageMove(id: number): void;
    /**
     * Cerrar la ventanta preview
     */
    closePreview(): void;
}
