import { OnInit, OnDestroy, ElementRef } from '@angular/core';
import { Observable } from 'rxjs';
import { LoadingIndicatorConfig } from '../interfaces/loading.interfaces';
/**
 * Componente que sera la capa del loading
 */
export declare class OverlayComponent implements OnInit, OnDestroy {
    private config;
    /**
     * Input que utlizaremos para obtner el foco del formulario
     */
    focusTrap: ElementRef;
    /**
     * Guardamos el subscribe para eliminarlo al final y no se quede en memoria
     */
    private isLoadingSub;
    /**
     * Obtenemos el actual elemento con el foco
     */
    private previousFocusTarget;
    /**
     * Pasaremos el foco al input focusTrap
     */
    private nextFocusTarget;
    /**
     * constructor
     * @param config Configuracion del spinner colores y componente a mostrar
     */
    constructor(config: LoadingIndicatorConfig);
    /**
     * Obtenemos el estado de loading y lo asignamos a un subscribe para eliminarlo
     * seleccionamos el foco por el estado del loading
     */
    ngOnInit(): void;
    /**
     * Destruir los subscribe creados
     */
    ngOnDestroy(): void;
    /**
     * obtemos el estado de loading
     */
    readonly isLoading$: Observable<boolean>;
    /**
     * obtenemos el color de background de fondo para el loading
     * en caso no este definido le damos el siguiete color
     * 'rgba(100, 100, 100, 0.3)'
     */
    readonly overlayColor: string;
    /**
     * Atrapamos el actual foco
     * dejamos el actual foco asignamos el foco al input creado en este componente
     */
    trapFocus(): void;
    /**
     * devolvemos el foco al anterior elemento que lo tenia
     */
    restoreFocus(): void;
    /**
     * si perdemos el foco en el input le devolveremos el foco a nextFocusTarget
     */
    disableKeyboardEvents(event: FocusEvent): void;
}
